@@ -1,3 +1,3 @@
 ARMAtoAR <- function(ar = 0, ma = 0, lag.max=20){
-  return(stats::ARMAtoMA(ar=-ma, ma=-ar, lag.max))
+  return(ARMAtoMA(ar=-ma, ma=-ar, lag.max))
 }
\ No newline at end of file
