@@ -8,17 +8,17 @@ function(series, L=c(3,3), M=50, max.freq=.05, col=4){
 ##   http://www.stat.ualberta.ca/%7Ewiens/wiens.html     
 ##                               
 ######################################
-ts     = stats::ts
-tsp    = stats::tsp
-par    = graphics::par
-plot   = graphics::plot
-dev.new = grDevices::dev.new
-abline = graphics::abline
-ccf    = stats::ccf
-ts.intersect = stats::ts.intersect 
-ts.plot = stats::ts.plot
-na.omit = stats::na.omit
-lines = graphics::lines
+#ts     = stats::ts
+#tsp    = stats::tsp
+#par    = graphics::par
+#plot   = graphics::plot
+#dev.new = grDevices::dev.new
+#abline = graphics::abline
+#ccf    = stats::ccf
+#ts.intersect = stats::ts.intersect 
+#ts.plot = stats::ts.plot
+#na.omit = stats::na.omit
+#lines = graphics::lines
 
 ######## Smoothing parameter (L) is odd
 ######## Number of estimates (M) is even
@@ -35,7 +35,7 @@ M = 2*floor(M/2)           # make sure M  is even
 # Compute the spectrum
 tspar = tsp(series)
 series = ts(series, frequency = 1)  # This script assumes frequency = 1 (so 0 < nu < .5)
-spectra = stats::spec.pgram(series, spans=L, plot = FALSE)
+spectra = spec.pgram(series, spans=L, plot = FALSE)
 
 
 A <- function(nu) {
