@@ -1,26 +1,22 @@
 acf2 <-
 function(series, max.lag=NULL, plot=TRUE, main=NULL, ylim=NULL, na.action=na.pass, ...){
-  acf       = stats::acf
-  pacf      = stats::pacf
-  frequency = stats::frequency
-  num       = length(series)
-  xfreq     = frequency(series)
+
+  num   = length(series)
+  xfreq = frequency(series)
 
   if (num < 3) stop("More than 2 observations are needed")
   if (num > 59 & is.null(max.lag))  max.lag = max(ceiling(10+sqrt(num)), 4*xfreq) 
-  if (num < 60 & is.null(max.lag))  max.lag = min(floor(6*log10(num+5)), num-2)
-  if (max.lag > (num-1)) stop("Number of lags exceeds number of observations")
+  if (num < 60 & is.null(max.lag))  max.lag =  floor(6*log10(num))
+  if (max.lag > (num-1)) max.lag = floor(6*log10(num)*(num<60) + (10+sqrt(num))*(num>59))
   if (is.null(main)) main = paste("Series: ",deparse(substitute(series)))
 
-  ACF  = acf(series, max.lag, plot=FALSE, na.action = na.action,...)$acf[-1]
-  PACF = pacf(series, max.lag, plot=FALSE, na.action = na.action, ...)$acf
-  LAG  = (1:max.lag)/xfreq
+  ACF  = acf(series, lag.max=max.lag, plot=FALSE, na.action = na.action,...)$acf[-1]
+  PACF = pacf(series, lag.max=max.lag, plot=FALSE, na.action = na.action, ...)$acf
 
  if(plot){
-   abline = graphics::abline
-   par = graphics::par
    U = (-1/num) + (2/sqrt(num))
    L = (-1/num) - (2/sqrt(num))
+   LAG  = (1:max.lag)/xfreq
    old.par <- par(no.readonly = TRUE)
    if (is.null(ylim)) { 
     minA=min(ACF)  
