@@ -11,7 +11,7 @@ function(series, order=1, lowess=FALSE, lowspan=.75, robust=TRUE,
       fam  = ifelse(robust, 'symmetric', 'gaussian') 
       y    = c(series)
       x    = c(time(series)) 
-      lo   = stats::predict(stats::loess(y ~ x, span=lowspan, family=fam), se=TRUE)
+      lo   = predict(loess(y ~ x, span=lowspan, family=fam), se=TRUE)
       trnd = ts(lo$fit, start=tspar[1], frequency=tspar[3])
     tsplot(series, col=col[1], ylab=ylab, ...)
     lines(trnd, col=col[2], lwd=2)
@@ -25,14 +25,16 @@ function(series, order=1, lowess=FALSE, lowspan=.75, robust=TRUE,
       invisible(cbind(trnd, L, U))  
     } else {
        x = as.vector(time(series))
-       u = stats::lm(series~ poly(x, order), na.action=NULL)
+       u = lm(series~ poly(x, order), na.action=NULL)
        if (results){ 
-            if (order==1) {time = x; u = stats::lm(series~ time, na.action=NULL)} 
-            uu = summary(u)
-            print(round(coef(uu),2))
+           if (order==1) {time = x; u =  lm(series~ time, na.action=NULL)} 
+           uu = summary(u) 
+           dimnames(uu$coefficients) <- list(names(u$coefficients), 
+                  c("Estimate", "     SE", " t.value", " p.value"))
+            print(round(coef(uu), 2))
             cat('Noise SE estimated as:', round(uu$sigma,2), 'on', uu$df[2], 'df', '\n')
           }
-      up = stats::predict(u, interval="confidence", level = 0.95)
+      up = predict(u, interval="confidence", level = 0.95)
       upts = ts(up, start=tspar[1], frequency=tspar[3])
       tsplot(series, col=col[1], ylab=ylab, ...)
       trnd = upts[,1]
@@ -45,3 +47,4 @@ function(series, order=1, lowess=FALSE, lowspan=.75, robust=TRUE,
       invisible(upts)
     }
  }
+
